<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="615"/>
        <source>MX Date &amp; Time</source>
        <translation>Ημερομηνία και ώρα του MX</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Ημερομηνία &amp;&amp; Ώρα</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>Hardware Clock</source>
        <translation>Ρολόι υλικού</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Εργαλεία για το ρολόι υλικού</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Λήψη πληροφοριών από το ρολόι υλικού και εμφάνιση στο παρακάτω πλαίσιο.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Ανάγνωση από το ρολόι υλικού</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Εφαρμογή διορθώσεων στο ρολόι υλικού.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Ρύθμιση διόρθωσης</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Μεταφορά ώρας</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Άμεση ρύθμιση του ρολογιού συστήματος ώστε να ταιριάζει με την τρέχουσα ώρα από το ρολόι υλικού.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Ρολόι υλικού σε ρολόι συστήματος</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Άμεση ρύθμιση του ρολογιού υλικού ώστε να ταιριάζει με την τρέχουσα ώρα από το ρολόι συστήματος.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Ρολόι συστήματος σε ρολόι υλικού</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Ενημέρωση του συντελεστή διόρθωσης όταν ρυθμίζεται το ρολόι υλικού.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Ενημέρωση διόρθωσης</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Ζώνη ώρας για το ρολόι υλικού</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Τοπική ώρα</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Τοπικός</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Παγκοσμίως ώρα συντονισμού (ή ώρα Greenwich)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Χρόνος δικτύου</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Μετακίνηση του επιλεγμένου στοιχείου προς τα κάτω</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Μετακίνηση του επιλεγμένου στοιχείου προς τα επάνω</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Αφαίρεση του στοιχείου από τη λίστα</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Προσθήκη στοιχείου στη λίστα</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Αυτόματη ενημέρωση του ρολογιού συστήματος από τους διακομιστές NTP:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Άμεση ενημέρωση του ρολογιού συστήματος από τους διακομιστές NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Ενημέρωση τώρα</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Λίστα διακομιστών NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="279"/>
        <source>Reading...</source>
        <translation>Ανάγνωση...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="293"/>
        <source>Adjusting...</source>
        <translation>Ρύθμιση...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="305"/>
        <location filename="../datetime.cpp" line="312"/>
        <source>System Clock</source>
        <translation>Ρολόι συστήματος</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="318"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Η ώρα %1 μεταφέρθηκε στο %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="321"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Η ώρα %1 δεν μεταφέρθηκε στο %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="361"/>
        <source>Updating...</source>
        <translation>Ενημέρωση...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="375"/>
        <source>The system clock was updated successfully.</source>
        <translation>Το ρολόι συστήματος ενημερώθηκε με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="377"/>
        <source>The system clock could not be updated.</source>
        <translation>Το ρολόι συστήματος δεν ενημερώθηκε.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="379"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Κανένας από τους διακομιστές NTP της λίστας δεν είναι ενεργοποιημένος.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="615"/>
        <source>About MX Date &amp; Time</source>
        <translation>Περί του MX Date &amp; Time</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="616"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="617"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Γραφικό πρόγραμμα για τον καθορισμό της ώρας και της ημερομηνίας στο MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="619"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="621"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Άδεια</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Αρχείο αλλαγών</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Ακύρωση</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="627"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Βοήθεια για το MX Date &amp; Time</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation type="unfinished">Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Κλείσιμο</translation>
    </message>
</context>
</TS>
